summaryrefslogtreecommitdiffstats
path: root/ksquirrel/ksquirrel-libs-configurator/klc.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'ksquirrel/ksquirrel-libs-configurator/klc.cpp')
-rw-r--r--ksquirrel/ksquirrel-libs-configurator/klc.cpp6
1 files changed, 3 insertions, 3 deletions
diff --git a/ksquirrel/ksquirrel-libs-configurator/klc.cpp b/ksquirrel/ksquirrel-libs-configurator/klc.cpp
index f510128..4a90161 100644
--- a/ksquirrel/ksquirrel-libs-configurator/klc.cpp
+++ b/ksquirrel/ksquirrel-libs-configurator/klc.cpp
@@ -28,11 +28,11 @@
#include "./klc.ui.h"
/*
* Constructs a KLC as a child of 'tqparent', with the
* name 'name' and widget flags set to 'f'.
*/
-KLC::KLC( TQWidget* tqparent, const char* name, WFlags fl )
- : TQWidget( tqparent, name, fl )
+KLC::KLC( TQWidget* parent, const char* name, WFlags fl )
+ : TQWidget( parent, name, fl )
{
if ( !name )
setName( "KLC" );
@@ -28,11 +28,11 @@
#include "./klc.ui.h"
/*
- * Constructs a KLC as a child of 'tqparent', with the
+ * Constructs a KLC as a child of 'parent', with the
* name 'name' and widget flags set to 'f'.
*/